%bcond_without pgm
%bcond_without unwind

Name:           zeromq
Version:        4.3.4
Release:        3%{?dist}
Summary:        Software library for fast, message-based applications

License:        LGPLv3+
URL:            https://zeromq.org
Source0:        https://github.com/%{name}/libzmq/archive/v%{version}/libzmq-%{version}.tar.gz

BuildRequires:  make
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  libsodium-devel
%if %{with unwind}
%ifarch %{arm} aarch64 hppa ia64 mips ppc %{power64} %{ix86} x86_64
BuildRequires:  libunwind-devel
%endif
%endif

%if %{with pgm}
BuildRequires:  openpgm-devel
BuildRequires:  krb5-devel
%endif

%description
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the ZeroMQ shared library.


%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}


%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -p1 -n libzmq-%{version}

# Remove bundled code.
rm -rf external/wepoll

# Fix permissions.
chmod -x src/xsub.hpp


%build
autoreconf -fi
%configure \
%if %{with pgm}
            --with-pgm \
            --with-libgssapi_krb5 \
%endif
            --with-libsodium \
%if %{with unwind}
%ifarch %{arm} aarch64 hppa ia64 mips ppc %{power64} %{ix86} x86_64
            --enable-libunwind \
%endif
%endif
            --disable-Werror \
            --disable-static
%make_build


%install
%make_install

# remove *.la
rm %{buildroot}%{_libdir}/libzmq.la


%check
make check V=1 || ( cat test-suite.log && exit 1 )



%ldconfig_scriptlets


%files
%doc README.md AUTHORS NEWS
%license COPYING COPYING.LESSER
%{_bindir}/curve_keygen
%{_libdir}/libzmq.so.5*
%{_mandir}/man3/zmq_*
%{_mandir}/man7/zmq_*
%{_mandir}/man7/zmq.*

%files devel
%{_libdir}/libzmq.so
%{_libdir}/pkgconfig/libzmq.pc
%{_includedir}/zmq*.h


%changelog
* Tue Mar 07 2023 Ben Woodard <woodard@redhat.com> - 4.3.4-3
- disable building with libunwind to fix C++ exceptions when a C applicaion loads
  a module written in C++ #2175966

* Tue Feb 02 2021 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.3.4-2
- Re-added aarch64

* Sat Jan 30 2021 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.3.4-1
- Upstream upgrade
- Fixes #1921879, #1921972, #1921973, #1921975, #1921976, #1921979, #1921981,
- #1921983, #1921983, #1921985, #1921987, #1921989, #1921992, #1921994

* Wed Sep 16 2020 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.3.3-1
- Upstream upgrade
- Fixes #1876738 and #1876689

* Sun Oct 27 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.3.2-1
- Initial build for EPEL 8

